@@ -26,9 +26,6 @@
 #ifndef PARENT_DEBUG
 #define PARENT_DEBUG 1
 #endif
-#ifndef DEBUG
-#define DEBUG 1
-#endif
 #endif
 
 void
@@ -224,6 +221,12 @@ handle_parent_connection (int s)
 	    do_output (s, resp, _offset_data (fsusage),
 		       0, NULL);
 	    break;
+    case GLIBTOP_CMND_PROC_IO:
+	    glibtop_get_proc_io_l
+		(server, &resp->u.data.proc_io, parameter);
+	    do_output (s, resp, _offset_data (proc_io),
+		       0, NULL);
+	    break;
 	case GLIBTOP_CMND_PPP:
 	    memcpy (&device, parameter, sizeof (device));
 	    glibtop_get_ppp_l
